# 2.6 Pin 模块API手册



## 前言

### 概述

本文档主要介绍machine模块下的Pin类API。

### 读者对象

本文档（本指南）主要适用于以下人员：

- 技术支持工程师
- 软件开发工程师

### 缩略词定义

| 简称 | 说明 |
| ---- | ---- |
| GPIO  |  General Purpose Input Output （通用输入/输出）  |

### 修订记录

| 文档版本号 | 修改说明 | 修改者     | 日期       |
| ---------- | -------- | ---------- | ---------- |
| V1.0       | 初版     | 软件部      | 2023-09-20 |

## 1. 概述

K230内部包含64个GPIO Pin，每个Pin可配置为输入或输出，可配置上下拉，可配置驱动能力。

## 2. API描述

Pin类位于machine模块下

### 示例

```python
from machine import Pin
# 实例化Pin2为输出
pin = Pin(2, Pin.OUT, pull=Pin.PULL_NONE, drive=7)
# 设置输出为高
pin.value(1)
# 设置输出为低
pin.value(0)
```

### 构造函数

```python
pin = Pin(index, mode, pull=Pin.PULL_NONE, drive=7)
```

【参数】

- index: 引脚号，取值:[0,63]
- mode: 输入或输出模式
- pull: 上下拉配置，可选参数，默认PULL_NONE
- drive: 驱动能力配置，可选参数，默认7

### init

```python
Pin.init(mode, pull=Pin.PULL_NONE, drive=7)
```

配置引脚模式，上下拉，驱动能力

【参数】

- mode: 输入或输出模式
- pull: 上下拉配置，可选参数，默认PULL_NONE
- drive: 驱动能力配置，可选参数，默认7

【返回值】

无

### value

```python
Pin.value([value])
```

获取引脚输入或设置引脚输出

【参数】

- value: 输出值，可选参数，如果不传参数则返回输入值

【返回值】

返回空或当前引脚输入值

### mode

```python
Pin.mode([mode])
```

获取或设置引脚输入输出模式

【参数】

- mode: 输入输出模式，可选参数，如果不传参数则返回当前输入输出模式

【返回值】

返回空或当前引脚输入输出模式

### pull

```python
Pin.pull([pull])
```

获取或设置引脚上下拉配置

【参数】

- pull: 上下拉配置，可选参数，如果不传参数则返回当前上下拉配置

【返回值】

返回空或当前引脚上下拉配置

### drive

```python
Pin.drive([drive])
```

获取或设置引脚驱动能力

【参数】

- drive: 驱动能力，可选参数，如果不传参数则返回当前驱动能力

【返回值】

返回空或当前引脚驱动能力

### on

```python
Pin.on()
```

设置输出高

【参数】

无

【返回值】

无

### off

```python
Pin.off()
```

设置输出低

【参数】

无

【返回值】

无

### high

```python
Pin.high()
```

设置输出高

【参数】

无

【返回值】

无

### low

```python
Pin.low()
```

设置输出低

【参数】

无

【返回值】

无
